@@ -20,7 +20,7 @@ our (
     $LEVEL_NAME_REGEX,
 );
 
-$VERSION = "0.90";
+$VERSION = "0.91";
 Readonly $VERSION;
 
 use Params::Validate qw(
@@ -344,7 +344,7 @@ sub dechunk {
 
     $accumulator->[$chunk->{sequence_number}] = $chunk->{data};
 
-    if ( scalar @{$accumulator} == $chunk->{sequence_count} ) {
+    if ( (scalar grep {defined} @{$accumulator}) == $chunk->{sequence_count} ) {
         return join '', @{$accumulator};
     }
     else {
@@ -516,7 +516,7 @@ Timestamp, defaults to time() from C<Time::HiRes>.
 
 =item level
 
-Integer, equal to the standard syslog levels, default is 1 (ALERT).
+Integer, equal to the standard C<syslog> levels, default is 1 (ALERT).
 
 =item facility
 
@@ -535,55 +535,55 @@ Deprecated, a warning will be issued.
 Parameters prefixed with an underscore (_) will be treated as an additional
 field. Allowed characters in field names are any word character (letter,
 number, underscore), dashes and dots. As per the specification '_id' is
-dissallowed.
+disallowed.
 
 =back
 
-=head2 encode( \% )
+=head2 C<encode( \% )>
 
 Accepts HASHREF to a structure representing a GELF message. The message
 will be converted validated with C<validate_message>.
 
 Returns a JSON encoded string representing the message.
 
-=head2 decode( $ )
+=head2 C<decode( $ )>
 
 Accepts a JSON encoded string representing the message. This will be
-convertd to a hashref and validated with C<validate_message>.
+converted to a hashref and validated with C<validate_message>.
 
 Returns a HASHREF representing the validated message with any defaulted
 values added to the data structure.
 
-=head2 compress( $ [, $] )
+=head2 C<compress( $ [, $] )>
 
 Accepts a string and compresses it. The second parameter is optional and
-can take the value 'zlib' or 'gzip', defaulting to 'gzip'.
+can take the value C<zlib> or C<gzip>, defaulting to C<gzip>.
 
 Returns a compressed string.
 
-=head2 uncompress( $ )
+=head2 C<uncompress( $ )>
 
-Accepts a string and uncompresses it. The compression method (gzip or zlib)
-is determined automatically. Uncompressed strings are passed through
-unaltered.
+Accepts a string and uncompresses it. The compression method (C<gzip> or
+C<zlib>) is determined automatically. Uncompressed strings are passed
+through unaltered.
 
 Returns an uncompressed string.
 
-=head2 enchunk( $ [, $] )
+=head2 C<enchunk( $ [, $] )>
 
 Accepts an encoded message (JSON string) and chunks it according to the
 GELF chunking protocol.
 
 The optional second parameter is the maximum size of the chunks to produce,
-this must be a positive integer or the special strings 'lan' or 'wan', see
-C<parse_size>. Defaults to 'wan'. A zero chunksize means no chunking will
-be applied.
+this must be a positive integer or the special strings C<'lan'> or C<'wan'>,
+see C<parse_size>. Defaults to 'wan'. A zero chunk size means no chunking
+will be applied.
 
 If the message size is greater than the maximum size then an array of
 chunks is retuned, otherwise the message is retuned unaltered as the first
 element of an array.
 
-=head2 dechunk( \@, \% )
+=head2 C<dechunk( \@, \% )>
 
 This facilitates reassembling a GELF message from a stream of chunks.
 
@@ -593,14 +593,15 @@ representing a decoded message chunk as produced by C<decode_chunk>.
 It returns undef if the accumulator is not complete, i.e. all chunks have
 not yet been passed it.
 
-Once the accumulator is complete it returns the dechunked message in the
+Once the accumulator is complete it returns the de-chunked message in the
 form of a string. Note that this message may still be compressed.
 
-Here is an example useage:
+Here is an example usage:
 
     sub process_chunks {
 
-        my @chunks; my $msg;
+        my @chunks;
+        my $msg;
 
         do {
             $msg = dechunk(\@chunks, decode_chunk(shift()));
@@ -609,11 +610,11 @@ Here is an example useage:
         return $msg;
     };
 
-=head2 is_chunked( $ )
+=head2 C<is_chunked( $ )>
 
 Accepts a string and returns a true value if it is a GELF message chunk.
 
-=head2 decode_chunk( $ )
+=head2 C<decode_chunk( $ )>
 
 Accepts a GELF message chunk and returns an ARRAYREF representing the
 chunk. The message consists of the following keys:
@@ -622,33 +623,33 @@ chunk. The message consists of the following keys:
 
 decode_chunk dies if the input is not a GELF chunk.
 
-=head2 parse_level( $ )
+=head2 C<parse_level( $ )>
 
-Accepts a syslog style level in the form of a number (1-7) or a string
-being one of 'emerg', 'alert', 'crit', 'err', 'warn', 'notice', 'info', or
-'debug'.
+Accepts a C<syslog> style level in the form of a number (1-7) or a string
+being one of 'C<emerg>', 'C<alert>', 'C<crit>', 'C<err>', 'C<warn>',
+'C<notice>', 'C<info>', or '<debug>'.
 
-The string forms may also be elongaged and will still be accpted. For
+The string forms may also be elongated and will still be accepted. For
 example 'err' and 'error' are equivalent.
 
-The associated syslog level is returned in numeric form.
+The associated C<syslog> level is returned in numeric form.
 
 parse_level dies upon invalid input.
 
-=head2 parse_size( $ )
+=head2 C<parse_size( $ )>
 
 Accepts integer specifying the chunk size or the special string values
-'lan' or 'wan' corresponding to 8154 or 1420 respectively. An explanation
+'C<lan>' or 'C<wan>' corresponding to 8154 or 1420 respectively. An explanation
 of these values is in the code.
 
-Returns the passed size or the value corresponding to the 'lan' or 'wan'.
+Returns the passed size or the value corresponding to the 'C<lan>' or 'C<wan>'.
 
 parse_size dies upon invalid input.
 
 =head1 CONSTANTS
 
 All Log::Gelf::Util constants are Readonly perl structures. You must use
-sigils when referencing them. They can be impored individually and are
+sigils when referencing them. They can be imported individually and are
 included when importing ':all';
 
 =head2 $GELF_MSG_MAGIC
